@@ -1,4 +1,24 @@
+import threading
 from urllib.parse import quote
+from wsgiref.simple_server import WSGIServer
+
+
+class BackgroundWSGIServer(WSGIServer):
+
+    def __init__(self, *args, **kwargs):
+        super().__init__(*args, **kwargs)
+        self.thread = None
+
+    def __enter__(self):
+        super().__enter__()
+        self.thread = threading.Thread(target=self.serve_forever)
+        self.thread.start()
+        return self
+
+    def __exit__(self, *args):
+        super().__exit__(*args)
+        self.shutdown()
+        self.thread.join()
 
 
 def hello_world_app(environ, start_response):
@@ -15,6 +35,7 @@ def redirect_app(environ, start_response):
     return [b'']
 
 
+# Based on:
 # https://www.python.org/dev/peps/pep-3333/#url-reconstruction
 def reconstruct_https_url(environ):
     url = 'https://'
@@ -23,13 +44,8 @@ def reconstruct_https_url(environ):
         url += environ['HTTP_HOST']
     else:
         url += environ['SERVER_NAME']
-
-        if environ['wsgi.url_scheme'] == 'https':
-            if environ['SERVER_PORT'] != '443':
-               url += ':' + environ['SERVER_PORT']
-        else:
-            if environ['SERVER_PORT'] != '80':
-               url += ':' + environ['SERVER_PORT']
+        if environ['SERVER_PORT'] != '443':
+            url += ':' + environ['SERVER_PORT']
 
     url += quote(environ.get('SCRIPT_NAME', ''))
     url += quote(environ.get('PATH_INFO', ''))
